@@ -1,9 +1,10 @@
+use Action::*;
+
 use crate::{
-    protocol::NecAppleCommand,
+    protocol::nec::AppleNecCommand,
     remotecontrol::{Action, DeviceType, RemoteControlModel},
     ProtocolId,
 };
-use Action::*;
 
 #[derive(Debug, Default)]
 #[cfg_attr(feature = "defmt", derive(defmt::Format))]
@@ -29,9 +30,9 @@ impl RemoteControlModel for Apple2009 {
     const DEVTYPE: DeviceType = DeviceType::Generic;
     const PROTOCOL: ProtocolId = ProtocolId::NecApple;
     const ADDRESS: u32 = 0;
-    type Cmd = NecAppleCommand;
+    type Cmd = AppleNecCommand;
 
-    fn decode(cmd: &NecAppleCommand) -> Option<Action> {
+    fn decode(cmd: &AppleNecCommand) -> Option<Action> {
         BUTTONS
             .iter()
             .find(|(c, _b)| c == &(cmd.command_page, cmd.command))
