@@ -1,11 +1,11 @@
+use Action::*;
+
 use crate::{
+    protocol::nec::SamsungNecCommand,
     remotecontrol::{Action, DeviceType, RemoteControlModel},
     ProtocolId,
 };
 
-use crate::protocol::NecSamsungCommand;
-use Action::*;
-
 #[derive(Debug, Default)]
 pub struct SamsungTv;
 
@@ -14,7 +14,7 @@ impl RemoteControlModel for SamsungTv {
     const DEVTYPE: DeviceType = DeviceType::TV;
     const PROTOCOL: ProtocolId = ProtocolId::NecSamsung;
     const ADDRESS: u32 = 7;
-    type Cmd = NecSamsungCommand;
+    type Cmd = SamsungNecCommand;
 
     const BUTTONS: &'static [(u32, Action)] = &[
         (2, Power),
