@@ -1,9 +1,10 @@
+use Action::*;
+
 use crate::{
-    protocol::Rc5Command,
+    protocol::rc5::Rc5Command,
     remotecontrol::{Action, DeviceType, RemoteControlModel},
     ProtocolId,
 };
-use Action::*;
 
 #[derive(Debug, Default)]
 #[cfg_attr(feature = "defmt", derive(defmt::Format))]
