@@ -1,11 +1,11 @@
+use Action::*;
+
 use crate::{
-    protocol::SbpCommand,
+    protocol::sbp::SbpCommand,
     remotecontrol::{Action, DeviceType, RemoteControlModel},
     ProtocolId,
 };
 
-use Action::*;
-
 #[derive(Debug, Default)]
 pub struct SamsungBluRayPlayer;
 
